@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -44,6 +44,7 @@ class Hash(proto.Message):
         r"""The algorithm used to compute the hash."""
         HASH_TYPE_UNSPECIFIED = 0
         SHA256 = 1
+        MD5 = 2
 
     type_ = proto.Field(proto.ENUM, number=1, enum=HashType,)
     value = proto.Field(proto.BYTES, number=2,)
@@ -56,8 +57,9 @@ class File(proto.Message):
     Attributes:
         name (str):
             The name of the file, for example:
-            "projects/p1/locations/us-
-            central1/repositories/repo1/files/a/b/c.txt".
+            "projects/p1/locations/us-central1/repositories/repo1/files/a%2Fb%2Fc.txt".
+            If the file ID part contains slashes, they are
+            escaped.
         size_bytes (int):
             The size of the File in bytes.
         hashes (Sequence[google.cloud.artifactregistry_v1beta2.types.Hash]):
@@ -84,8 +86,9 @@ class ListFilesRequest(proto.Message):
 
     Attributes:
         parent (str):
-            The name of the parent resource whose files
-            will be listed.
+            The name of the repository whose files will
+            be listed. For example:
+            "projects/p1/locations/us-central1/repositories/repo1
         filter (str):
             An expression for filtering the results of the request.
             Filter rules are case insensitive. The fields eligible for
